import json

import requests



class ApiviewClient(object):

    def __init__(self):
        pass

    def get(self, url, params):
        response = requests.get(url, params=params)
        response_data = json.loads(response.content)
        return response_data

    def post(self, url, params):
        response = requests.post(url, json=params)
        response_data = json.loads(response.content)
        return response_data




""" not ready...

class Service(object):
    
    def __call__(self, *args, **kwargs):
        return self.main(*args, **kwargs)

    @classmethod
    def serve(cls, *args, **kwargs):
        return cls()(*args, **kwargs)


class PingService(Service):

    def main(self):
        return "pong"

class EchoService(Service):

    def main(self, msg):
        return msg


 
@apiview
@cache("test:ping")
def ping():
    return PingService.serve()

@apiview
@cache("test:echo", related_services=[PingService])
def echo(msg):
    return PingService.serve(msg)

"""